// Copyright (c) 2004 David Muse
// See the COPYING file for more information

	private:
		crypt();
		crypt(const crypt &c);
		crypt	&operator=(const crypt &c);
		~crypt();
